==> servicecatalog-model-6.3.0-sources.jar: io/fabric8/servicecatalog/api/model/ServiceClassSpecFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface ServiceClassSpecFluent<A extends ServiceClassSpecFluent<A>> extends Fluent<A>{
  public Boolean getBindable();
  public A withBindable(Boolean bindable);
  public Boolean hasBindable();
  public Boolean getBindingRetrievable();
  public A withBindingRetrievable(Boolean bindingRetrievable);
  public Boolean hasBindingRetrievable();
  public A addToDefaultProvisionParameters(String key,Object value);
  public A addToDefaultProvisionParameters(Map<String,Object> map);
  public A removeFromDefaultProvisionParameters(String key);
  public A removeFromDefaultProvisionParameters(Map<String,Object> map);
  public Map<String,Object> getDefaultProvisionParameters();
  public <K,V>A withDefaultProvisionParameters(Map<String,Object> defaultProvisionParameters);
  public Boolean hasDefaultProvisionParameters();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public String getExternalID();
  public A withExternalID(String externalID);
  public Boolean hasExternalID();
  public A addToExternalMetadata(String key,Object value);
  public A addToExternalMetadata(Map<String,Object> map);
  public A removeFromExternalMetadata(String key);
  public A removeFromExternalMetadata(Map<String,Object> map);
  public Map<String,Object> getExternalMetadata();
  public <K,V>A withExternalMetadata(Map<String,Object> externalMetadata);
  public Boolean hasExternalMetadata();
  public String getExternalName();
  public A withExternalName(String externalName);
  public Boolean hasExternalName();
  public Boolean getPlanUpdatable();
  public A withPlanUpdatable(Boolean planUpdatable);
  public Boolean hasPlanUpdatable();
  public A addToRequires(Integer index,String item);
  public A setToRequires(Integer index,String item);
  public A addToRequires(java.lang.String... items);
  public A addAllToRequires(Collection<String> items);
  public A removeFromRequires(java.lang.String... items);
  public A removeAllFromRequires(Collection<String> items);
  public List<String> getRequires();
  public String getRequire(Integer index);
  public String getFirstRequire();
  public String getLastRequire();
  public String getMatchingRequire(Predicate<String> predicate);
  public Boolean hasMatchingRequire(Predicate<String> predicate);
  public A withRequires(List<String> requires);
  public A withRequires(java.lang.String... requires);
  public Boolean hasRequires();
  public String getServiceBrokerName();
  public A withServiceBrokerName(String serviceBrokerName);
  public Boolean hasServiceBrokerName();
  public A addToTags(Integer index,String item);
  public A setToTags(Integer index,String item);
  public A addToTags(java.lang.String... items);
  public A addAllToTags(Collection<String> items);
  public A removeFromTags(java.lang.String... items);
  public A removeAllFromTags(Collection<String> items);
  public List<String> getTags();
  public String getTag(Integer index);
  public String getFirstTag();
  public String getLastTag();
  public String getMatchingTag(Predicate<String> predicate);
  public Boolean hasMatchingTag(Predicate<String> predicate);
  public A withTags(List<String> tags);
  public A withTags(java.lang.String... tags);
  public Boolean hasTags();
  public A withBindable();
  public A withBindingRetrievable();
  public A withPlanUpdatable();
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceClassSpecFluent.java <==
package io.fabric8.servicecatalog.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ServiceClassSpecFluent<A extends ServiceClassSpecFluent<A>> extends Fluent<A>{
  public Boolean getBindable();
  public A withBindable(Boolean bindable);
  public Boolean hasBindable();
  public Boolean getBindingRetrievable();
  public A withBindingRetrievable(Boolean bindingRetrievable);
  public Boolean hasBindingRetrievable();
  public A addToDefaultProvisionParameters(String key,Object value);
  public A addToDefaultProvisionParameters(Map<String,Object> map);
  public A removeFromDefaultProvisionParameters(String key);
  public A removeFromDefaultProvisionParameters(Map<String,Object> map);
  public Map<String,Object> getDefaultProvisionParameters();
  public <K,V>A withDefaultProvisionParameters(Map<String,Object> defaultProvisionParameters);
  public Boolean hasDefaultProvisionParameters();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public String getExternalID();
  public A withExternalID(String externalID);
  public Boolean hasExternalID();
  public A addToExternalMetadata(String key,Object value);
  public A addToExternalMetadata(Map<String,Object> map);
  public A removeFromExternalMetadata(String key);
  public A removeFromExternalMetadata(Map<String,Object> map);
  public Map<String,Object> getExternalMetadata();
  public <K,V>A withExternalMetadata(Map<String,Object> externalMetadata);
  public Boolean hasExternalMetadata();
  public String getExternalName();
  public A withExternalName(String externalName);
  public Boolean hasExternalName();
  public Boolean getPlanUpdatable();
  public A withPlanUpdatable(Boolean planUpdatable);
  public Boolean hasPlanUpdatable();
  public A addToRequires(int index,String item);
  public A setToRequires(int index,String item);
  public A addToRequires(java.lang.String... items);
  public A addAllToRequires(Collection<String> items);
  public A removeFromRequires(java.lang.String... items);
  public A removeAllFromRequires(Collection<String> items);
  public List<String> getRequires();
  public String getRequire(int index);
  public String getFirstRequire();
  public String getLastRequire();
  public String getMatchingRequire(Predicate<String> predicate);
  public Boolean hasMatchingRequire(Predicate<String> predicate);
  public A withRequires(List<String> requires);
  public A withRequires(java.lang.String... requires);
  public Boolean hasRequires();
  public String getServiceBrokerName();
  public A withServiceBrokerName(String serviceBrokerName);
  public Boolean hasServiceBrokerName();
  public A addToTags(int index,String item);
  public A setToTags(int index,String item);
  public A addToTags(java.lang.String... items);
  public A addAllToTags(Collection<String> items);
  public A removeFromTags(java.lang.String... items);
  public A removeAllFromTags(Collection<String> items);
  public List<String> getTags();
  public String getTag(int index);
  public String getFirstTag();
  public String getLastTag();
  public String getMatchingTag(Predicate<String> predicate);
  public Boolean hasMatchingTag(Predicate<String> predicate);
  public A withTags(List<String> tags);
  public A withTags(java.lang.String... tags);
  public Boolean hasTags();
  public A withBindable();
  public A withBindingRetrievable();
  public A withPlanUpdatable();
  
}
